==> style-o-matic-1.1.5.tgz: package/es/components/App/App.js <==
var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import _ from "lodash";
import { CoreComponent, setCorePropDefaults, getValidProps, ROLE } from "../../lib";
import "./App.css";

var App = (_temp2 = _class = function (_CoreComponent) {
  _inherits(App, _CoreComponent);

  function App() {
    var _temp, _this, _ret;

    _classCallCheck(this, App);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args))), _this), _this.parseContainers = function (children) {
      var drawer = [];
      var header = [];
      var footer = [];
      var main = [];
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          switch (child.props.uirole) {
            case ROLE.DRAWER:
              drawer.push(child);
              return null;
            case ROLE.HEADER:
              header.push(child);
              return null;
            case ROLE.FOOTER:
              footer.push(child);
              return null;
            default:
              main.push(child);
              return null;
          }
        }
        return null;
      });
      var output = [];
      if (header.length > 0) {
        output = _.concat(output, header);
      }
      output.push(React.createElement(
        "div",
        { className: "ui-app-container", key: "app-drawer" },
        drawer,
        main
      ));
      if (footer.length > 0) {
        output = _.concat(output, footer);
      }
      return output;
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  App.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var containers = this.parseContainers(children);

    return React.createElement(
      Component,
      props,
      containers
    );
  };

  return App;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.APP
}), _temp2);


export default App;

==> style-o-matic-1.1.37.tgz: package/es/components/App/App.js <==
var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import _ from "lodash";
import { CoreComponent, getCorePropDefaults, getValidProps, ROLE } from "../../lib";
import "./App.css";

var App = (_temp2 = _class = function (_CoreComponent) {
  _inherits(App, _CoreComponent);

  function App() {
    var _temp, _this, _ret;

    _classCallCheck(this, App);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args))), _this), _this.parseContainers = function (children) {
      var drawer = [];
      var header = [];
      var footer = [];
      var main = [];
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          switch (child.props.uirole) {
            case ROLE.DRAWER:
              drawer.push(child);
              return null;
            case ROLE.HEADER:
              header.push(child);
              return null;
            case ROLE.FOOTER:
              footer.push(child);
              return null;
            default:
              main.push(child);
              return null;
          }
        }
        return null;
      });
      var output = [];
      if (header.length > 0) {
        output = _.concat(output, header);
      }
      output.push(React.createElement(
        "div",
        { className: "ui-app-container", key: "app-drawer" },
        drawer,
        main
      ));
      if (footer.length > 0) {
        output = _.concat(output, footer);
      }
      return output;
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  App.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var containers = this.parseContainers(children);

    return React.createElement(
      Component,
      props,
      containers
    );
  };

  return App;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.APP
}), _temp2);


export default App;
